/*******************************************************************************
* File Name: m_ss.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "m_ss.h"


/*******************************************************************************
* Function Name: m_ss_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void m_ss_Write(uint8 value) 
{
    uint8 staticBits = (m_ss_DR & (uint8)(~m_ss_MASK));
    m_ss_DR = staticBits | ((uint8)(value << m_ss_SHIFT) & m_ss_MASK);
}


/*******************************************************************************
* Function Name: m_ss_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void m_ss_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(m_ss_0, mode);
}


/*******************************************************************************
* Function Name: m_ss_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro m_ss_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 m_ss_Read(void) 
{
    return (m_ss_PS & m_ss_MASK) >> m_ss_SHIFT;
}


/*******************************************************************************
* Function Name: m_ss_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 m_ss_ReadDataReg(void) 
{
    return (m_ss_DR & m_ss_MASK) >> m_ss_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(m_ss_INTSTAT) 

    /*******************************************************************************
    * Function Name: m_ss_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 m_ss_ClearInterrupt(void) 
    {
        return (m_ss_INTSTAT & m_ss_MASK) >> m_ss_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
