/*******************************************************************************
* File Name: s_clk.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "s_clk.h"


/*******************************************************************************
* Function Name: s_clk_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void s_clk_Write(uint8 value) 
{
    uint8 staticBits = (s_clk_DR & (uint8)(~s_clk_MASK));
    s_clk_DR = staticBits | ((uint8)(value << s_clk_SHIFT) & s_clk_MASK);
}


/*******************************************************************************
* Function Name: s_clk_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void s_clk_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(s_clk_0, mode);
}


/*******************************************************************************
* Function Name: s_clk_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro s_clk_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 s_clk_Read(void) 
{
    return (s_clk_PS & s_clk_MASK) >> s_clk_SHIFT;
}


/*******************************************************************************
* Function Name: s_clk_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 s_clk_ReadDataReg(void) 
{
    return (s_clk_DR & s_clk_MASK) >> s_clk_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(s_clk_INTSTAT) 

    /*******************************************************************************
    * Function Name: s_clk_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 s_clk_ClearInterrupt(void) 
    {
        return (s_clk_INTSTAT & s_clk_MASK) >> s_clk_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
