/*******************************************************************************
* File Name: m_miso.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "m_miso.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 m_miso__PORT == 15 && ((m_miso__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: m_miso_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void m_miso_Write(uint8 value) 
{
    uint8 staticBits = (m_miso_DR & (uint8)(~m_miso_MASK));
    m_miso_DR = staticBits | ((uint8)(value << m_miso_SHIFT) & m_miso_MASK);
}


/*******************************************************************************
* Function Name: m_miso_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void m_miso_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(m_miso_0, mode);
}


/*******************************************************************************
* Function Name: m_miso_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro m_miso_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 m_miso_Read(void) 
{
    return (m_miso_PS & m_miso_MASK) >> m_miso_SHIFT;
}


/*******************************************************************************
* Function Name: m_miso_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 m_miso_ReadDataReg(void) 
{
    return (m_miso_DR & m_miso_MASK) >> m_miso_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(m_miso_INTSTAT) 

    /*******************************************************************************
    * Function Name: m_miso_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 m_miso_ClearInterrupt(void) 
    {
        return (m_miso_INTSTAT & m_miso_MASK) >> m_miso_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
