/*******************************************************************************
* File Name: s_ss.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "s_ss.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 s_ss__PORT == 15 && ((s_ss__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: s_ss_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void s_ss_Write(uint8 value) 
{
    uint8 staticBits = (s_ss_DR & (uint8)(~s_ss_MASK));
    s_ss_DR = staticBits | ((uint8)(value << s_ss_SHIFT) & s_ss_MASK);
}


/*******************************************************************************
* Function Name: s_ss_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void s_ss_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(s_ss_0, mode);
}


/*******************************************************************************
* Function Name: s_ss_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro s_ss_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 s_ss_Read(void) 
{
    return (s_ss_PS & s_ss_MASK) >> s_ss_SHIFT;
}


/*******************************************************************************
* Function Name: s_ss_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 s_ss_ReadDataReg(void) 
{
    return (s_ss_DR & s_ss_MASK) >> s_ss_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(s_ss_INTSTAT) 

    /*******************************************************************************
    * Function Name: s_ss_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 s_ss_ClearInterrupt(void) 
    {
        return (s_ss_INTSTAT & s_ss_MASK) >> s_ss_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
